@@ -30,7 +30,7 @@ except ImportError:
 
     base64.encodebytes = base64.encodestring
 
-from .commons import synchronized_with_attr, truncate
+from .commons import synchronized_with_attr, truncate, python_version_bellow
 from .params import group_key, parse_key, is_valid
 from .server import get_server_list
 from .files import read_file, save_file, delete_file
@@ -39,7 +39,7 @@ logging.basicConfig()
 logger = logging.getLogger()
 
 DEBUG = False
-VERSION = "0.4.6"
+VERSION = "0.4.9"
 
 DEFAULT_GROUP_NAME = "DEFAULT_GROUP"
 DEFAULT_NAMESPACE = ""
@@ -68,7 +68,7 @@ def _refresh_session_ak_and_sk_patch(self):
 
 
 def _check_session_credential_patch(self):
-    expiration = self._expiration if isinstance(self._expiration, (float, int))\
+    expiration = self._expiration if isinstance(self._expiration, (float, int)) \
         else time.mktime(datetime.strptime(self._expiration, "%Y-%m-%dT%H:%M:%SZ").timetuple())
     now = time.mktime(time.gmtime())
     if expiration - now < 3 * 60:
@@ -190,7 +190,7 @@ class ACMClient:
             logger.setLevel(logging.DEBUG)
             ACMClient.debug = True
 
-    def __init__(self, endpoint, namespace=None, ak=None, sk=None, ram_role_name=None):
+    def __init__(self, endpoint, namespace=None, ak=None, sk=None, ram_role_name=None, unit_name=None):
         self.endpoint = endpoint
         self.namespace = namespace or DEFAULT_NAMESPACE or ""
         self.ak = ak
@@ -228,6 +228,7 @@ class ACMClient:
         self.kms_client = None
         self.no_snapshot = False
         self.sts_token = None
+        self.unit_name = unit_name
 
         logger.info("[client-init] endpoint:%s, tenant:%s" % (endpoint, namespace))
 
@@ -255,7 +256,8 @@ class ACMClient:
             try:
                 time.sleep(30)
                 logger.debug("[refresh-server] try to refresh server list")
-                server_list = get_server_list(self.endpoint, 443 if self.tls_enabled else 8080, self.cai_enabled)
+                server_list = get_server_list(self.endpoint, 443 if self.tls_enabled else 8080, self.cai_enabled,
+                                              self.unit_name)
                 logger.debug(
                     "[refresh-server] server_num:%s server_list:%s" % (len(server_list), server_list))
                 if not server_list:
@@ -279,7 +281,8 @@ class ACMClient:
         if self.server_list is None:
             with self.server_list_lock:
                 logger.info("[get-server] server list is null, try to initialize")
-                server_list = get_server_list(self.endpoint, 443 if self.tls_enabled else 8080, self.cai_enabled)
+                server_list = get_server_list(self.endpoint, 443 if self.tls_enabled else 8080, self.cai_enabled,
+                                              self.unit_name)
                 if not server_list:
                     logger.error("[get-server] empty server_list get from %s" % self.endpoint)
                     return None
@@ -669,8 +672,8 @@ class ACMClient:
                 req = Request(url=server_url + url, data=urlencode(data).encode() if data else None,
                               headers=all_headers)
 
-                # for python2.6 compatibility
-                if sys.version_info[0] == 2 and sys.version_info[1] == 6:
+                # for python version compatibility
+                if python_version_bellow("2.7.9"):
                     resp = urlopen(req, timeout=timeout)
                 else:
                     if self.tls_enabled and is_ip_address:
@@ -740,9 +743,11 @@ class ACMClient:
                 changed_keys = [group_key(*i) for i in parse_pulling_result(resp.read())]
                 logger.debug("[do-pulling] following keys are changed from server %s" % truncate(str(changed_keys)))
             except ACMException as e:
-                logger.error("[do-pulling] acm exception: %s" % str(e))
+                logger.error("[do-pulling] acm exception: %s, waiting for recovery" % str(e))
+                time.sleep(1)
             except Exception as e:
-                logger.exception("[do-pulling] exception %s occur, return empty list" % str(e))
+                logger.exception("[do-pulling] exception %s occur, return empty list, waiting for recovery" % str(e))
+                time.sleep(1)
 
             for cache_key, cache_data in cache_pool.items():
                 cache_data.is_init = False
