@@ -13,6 +13,7 @@ except ImportError:
 logger = logging.getLogger("acm")
 
 ADDRESS_URL_PTN = "http://%s/diamond-server/diamond"
+ADDRESS_URL_PTN_FOR_UNIT = "http://%s/diamond-server/diamond-unit-%s?nofix=1"
 
 ADDRESS_SERVER_TIMEOUT = 3  # in seconds
 
@@ -25,14 +26,24 @@ def is_ipv4_address(address):
     return True
 
 
-def get_server_list(endpoint, default_port=8080, cai_enabled=True):
+def get_server_list(endpoint, default_port=8080, cai_enabled=True, unit_name=None):
     server_list = list()
     if not cai_enabled:
         logger.info("[get-server-list] cai server is not used, regard endpoint:%s as server." % endpoint)
         content = endpoint.encode()
     else:
         try:
-            content = urlopen(ADDRESS_URL_PTN % endpoint, timeout=ADDRESS_SERVER_TIMEOUT).read()
+            # use 8080 as default port.
+            if ":" not in endpoint:
+                endpoint = endpoint + ":8080"
+
+            url = ADDRESS_URL_PTN % endpoint
+
+            if unit_name:
+                logger.info("[get-server-list] getting server for unit:%s" % unit_name)
+                url = ADDRESS_URL_PTN_FOR_UNIT % (endpoint, unit_name)
+
+            content = urlopen(url, timeout=ADDRESS_SERVER_TIMEOUT).read()
             logger.debug("[get-server-list] content from endpoint:%s" % content)
         except (URLError, OSError, socket.timeout) as e:
             logger.error("[get-server-list] get server from %s failed, cause:%s" % (endpoint, e))
